@@ -2,4 +2,4 @@
 A package to handle GNU Scientific Library (GSL) constants for python.
 """
 
-from gslconsts import *
+import gslconsts.consts
